@@ -18,7 +18,7 @@ def _log(msg, application, level,execution_time, environment, user_id=None, extr
             "extra_data": extra_data,
             "timestamp": now
         }
-        logging.basicConfig(filename=now+'.log', filemode='w', format='%(message)s')
+        logging.basicConfig(filename=config('DIR')+now+'.log', filemode='w', format='%(message)s')
         logging.warning(json.dumps(data))
         return data
     
@@ -28,7 +28,6 @@ def _notify(msg):
 
 
 def warning(msg, application, execution_time, environment, user_id=None, extra_data=None):
-        print(config('WARNING'))
         _log(msg, application,config('WARNING') ,execution_time, environment, user_id, extra_data)
         
 def info(msg, application, execution_time, environment, user_id=None, extra_data=None):
