@@ -5,7 +5,7 @@ from decouple import config
 import requests
 
 def main():
-    return "DDD"
+    return None
 class logs_hub:
 
 
